@@ -6,6 +6,7 @@ use warnings;
 use DBI;
 use DBIx::Recordset;
 
+
 require Exporter;
 
 our @ISA = qw(Exporter);
@@ -17,18 +18,24 @@ our @ISA = qw(Exporter);
 # This allows declaration	use DBIx::Recordset::Playground ':all';
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
+our %EXPORT_TAGS = ( 'all' => [ qw(
+	
+) ] );
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw(	
 );
 
-our $VERSION = sprintf '%s', q$Revision: 1.12 $ =~ /Revision:\s+(\S+)\s+/ ;
+our $VERSION = '1.2';
+
 
 # Preloaded methods go here.
 
 
+
+
+
 1;
 __END__
 # Below is stub documentation for your module. You'd better edit it!
@@ -52,7 +59,7 @@ Let the games begin!
 
 =head1 Preliminaries:
 
-=head2 Our Generic Connection/Library Script
+=head2 Our Generic Connection/Library Script:
 
 This script contains our connection information and a variety of
 convenience subroutines. The existence of these points to how we might
@@ -68,20 +75,9 @@ basics.
  
  # change to match your local connection parameters
  
- my ($dsn, $user, $pass);
- 
- # mysql
- {
-   last;
-   $dsn = 'DBI:mysql:database=princepawn;host=localhost';
-   $user='princepawn';
-   $pass='money1';
- }
- 
- # psql
-   $dsn = 'DBI:Pg:dbname=test;host=localhost';
- 
- 
+ my  $dsn = 'DBI:mysql:database=princepawn;host=localhost';
+ my  $user='princepawn';
+ my  $pass='money1';
  my  $attr= { RaiseError => 1 };
  
  
@@ -136,80 +132,14 @@ basics.
 
 The schema description is given in:
 
-L<DBSchema::Sample|DBSchema::Sample>
+L<DBSchema::Sample|DBSchema::Sample>.
 
 which is built via:
 
   perl -MDBSchema::Sample -e load
 
 
-=head1 LIVING CODE SAMPLES
-
-=head2 Building Where Clauses
-
-=head3 FIELD $cmp A OR FIELD $cmp B or FIELD $cmp C ...
-
- #
- #   scripts/build-where/or-conjunct.pl
- #
- 
- require '../dbconn.pl';
- use DBIx::Recordset;
- use strict;
- 
- use vars qw(*set);
- 
- # Find all authors whose phone number is in area code 801 or 415
- 
- my @area_code = qw(801 415);
- 
- *set =
-   DBIx::Recordset -> Search
-   ({
-     conn_dbh(),
-     '!Table'   => 'authors',
-     '*phone'   => 'LIKE',
-       phone    => ( join "\t", map { "$_%" } @area_code ),
-    });
- 
- while ($set->Next) {
-     print Dumper(\%set)
- }
-
-
-=head4 Specialization of above when A, B, C not tab separated
-
- #
- #   scripts/build-where/or-conjunct-valuesplit.pl
- #
- 
- require '../dbconn.pl';
- use DBIx::Recordset;
- use strict;
- 
- use vars qw(*set);
- 
- # Find all authors whose zip is 94705, 94152 or 94609
- 
- my $zip = "94705
- 
- 84152\t94609";
- 
- 
- 
- *set =
-   DBIx::Recordset -> Search
-   ({
-     conn_dbh(),
-     '!Table'   => 'authors',
-      zip      => $zip,
-     '$valuesplit' => '\s+'
-    });
- 
- while ($set->Next) {
-     print Dumper(\%set)
- }
-
+=head1 SYNOPSIS
 
 =head2 Selecting data with where criteria in a hash
 
@@ -291,34 +221,6 @@ This is useful when your have formdata in a hash for instance.
  warn $rs{au_fname};
 
 
-=head2 Selecting data using a full SQL query
-
-In Recordset > 0.24, one can input a full query for processing:
-
- #
- #   scripts/select-using-query.pl
- #
- 
- require 'dbconn.pl';
- use DBIx::Recordset;
- use strict;
- 
- use vars qw(*set);
- 
- *set =
-   DBIx::Recordset -> Search
-   ({
-     '!DataSource' => dbh(),
-     '$max' => 4,
-     '!Query' => 'SELECT * FROM AUTHORS'
-    });
- 
- while ($set->Next) {
-     print Dumper(\%set)
- }
- 
-
-
 =head2 Update
 
  #
@@ -441,189 +343,6 @@ In Recordset > 0.24, one can input a full query for processing:
  }
 
 
-=head2 Filtering Data on Input/Output to/from Database
-
- #
- #   scripts/filter-authors.pl
- #
- 
- require 'dbconn.pl';
- use DBIx::Recordset;
- use strict;
- 
- use vars qw(*set);
- 
- *set =
-   DBIx::Recordset -> Search
-   ({
-     conn_dbh(), author_table(),
-     '$max' => 10,
-     '!Filter' => {
- 		  DBI::SQL_VARCHAR => [
- 				       undef, # no input filtering
- 				       sub { uc (shift()) }
- 				      ]
- 		  }
-    });
- 
- 
- while ($set->Next) {
-     print Dumper(\%set)
- }
- 
-
-
-
-=head2 Tying a Table to a Hash for Easy Lookup by Primary Key
-
- #
- #   scripts/hash-as-row-key.pl
- #
- 
- require 'dbconn.pl';
- use DBIx::Recordset;
- use strict;
- use vars qw(*set);
- 
- *set = DBIx::Recordset -> Setup
-   ({
-     conn_dbh(),
-     '!Table'	    => 'authors',
-     '!HashAsRowKey' => 1,
-     '!PrimKey'      => 'au_id'
-    });
- 
- 
- my @au_id = qw( 409-56-7008  213-46-8915 998-72-3567 );
- 
- 
- warn Dumper($set{$_}) for @au_id;
-
-
-=head2 Tying Hashes with Expirable Caches to Databases 
-
-L<DBIx::Recordset|DBIx::Recordset> 
-allows you to tie a hash to a database table, and retrieve the
-records of the table via the hash's key. You can tie the entire table
-or create an expirable "view" of a subset of the table 
-via Recordset's C<!PreFetch>
-option. Your view can be expired based on a fixed amount of seconds or
-via a boolean subroutine which accepts the (tied hash via a scalar?) 
-as an argument.
-
-
- #
- #   scripts/prefetch-expire.pl
- #
- 
- #!/usr/bin/perl
- 
- require 'dbconn.pl';
- use DBIx::Recordset;
- use strict;
- 
- # This program repeatedly presents sales data on STDOUT, refreshing 
- # the view every $view_refresh seconds. It refreshes its 
- # model (from the database) every $model_refresh seconds.
- 
- # The default values for $model_refresh and $view_refresh imply that 
- # the model will refreshed after 2.6 view refreshes or practically speaking
- # on every 3rd view refresh.
- 
- # You can verify that it makes new hits on the database by noting the
- # DBIx::Recordset log messages. You will see this after every 3 view
- # displays:
- # DB:  'SELECT * FROM sales     ORDER BY sonum DESC  LIMIT 6' bind_values=<> bind_types=<>
- 
- # To spice things up, you can open a different terminal window and run
- # prefetch-insert.pl, which will insert a new record into the sales table
- # every $x seconds.
- 
- # This program requires a version of DBIx::Recordset > 0.24, which is the 
- # current CPAN release. Or you can apply the patch recently posted to
- # the embperl@perl.apache.org mailing list.
- 
- my $model_refresh = 13;
- my $view_refresh  = 5;
- 
- use vars qw(%sales);
- 
- tie %sales, 'DBIx::Recordset::Hash',
-   {
-    conn_dbh(),
-    '!Table' => 'sales',
-    '!PreFetch' => {
- 		   '$max'    => 5,
- 		   '$order'  => 'sonum DESC'
- 		  },
-    '!PrimKey'  => 'sonum',
-    '!Expires'  => $model_refresh
-   };
- 
- sub bynumber { $a <=> $b }
- 
- while (1) {
- 
-   my (@key) = keys %sales;
-   print $sales{$_}{sonum}, $/ for sort bynumber @key;
-   sleep $view_refresh;
-   print $/;
- 
- }
- 
-
-
- #
- #   scripts/prefetch-insert.pl
- #
- 
- require 'dbconn.pl';
- use DBIx::Recordset;
- use strict;
- 
- 
- # This program takes one argument, an integer indicating how often it should
- # insert a random record into the sales table.
- 
- my $insert_frequency = shift or die 'must specify insert frequency';
- 
- use vars qw(*set);
- 
- sub rand_ponum {
-   sprintf "%s%d%s", chr(65 + rand 25), rand 400 + rand 1000, 
-     lc chr(65 + rand 25);
- }
- 
- 
- *set = DBIx::Recordset->Search
-   ({
-     conn_dbh(),
-     '!Table'  => 'sales',
-     '!Fields' => 'max(sonum) as max_id',
-     });
- 
- my $max_id = $set{max_id};
- 
- 
- while (1) {
- 
-   DBIx::Recordset->Insert
-       (
-        {
- 	conn_dbh(),
- 	'!Table'  => 'sales',
- 	sonum     => ++$max_id,
- 	stor_id   => (sprintf "%d", 7000 + rand 1000),
- 	ponum     => rand_ponum,
- 	sdate     => '2003-10-22'
-        }
-        );
- 
-   sleep $insert_frequency;
- 
- }
-
-
 =head1
 
 Most functions which set up an object return a B<typeglob>. A typeglob
