@@ -1,5 +1,3 @@
-#!/usr/bin/perl
-
 print $/;
 print " Changes should be made to Playground.tt *not* Playground.pm \n";
 print " Changes should be made to MANIFEST.sans-scripts *not* MANIFEST \n";
@@ -11,13 +9,8 @@ print $/;
 
 #`cd scripts; ../delete-whitespace.pl; ../manifest-files.pl`;
 
-my @system = qw(cvs commit);
-system(@system) == 0 or die "system @system failed: $?";
-
-
 `perl tt.pl Playground.tt`;
 rename('Playground.tt-out', 'Playground.pm');
-`pod2html Playground.pm > Playground.html`;
 
 open M, ">MANIFEST";
 
@@ -27,5 +20,15 @@ print M $_, $/ while <scripts/*.pl>;
 
 print `perl Makefile.PL PREFIX=$ENV{PREFIX}`;
 print `make install`;
-print `rm *.tar.gz` ;
 print `make tardist`;
+
+print <<'EOTEXT';
+Now goto a cygwin shell and type
+
+  perl Makefile.PL PREFIX=$PREFIX
+  make tardist
+  upload-cpan.pl $release
+
+# dont you just love Windows?
+EOTEXT
+
